@@ -1,7 +1,7 @@
 #! /bin/false
 # vim: set autoindent shiftwidth=4 tabstop=4:
 
-# Conversion routines for ISO-8859-4.
+# Conversion routines for ISO-8859-9.
 # Copyright (C) 2002-2017 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-package Locale::RecodeData::ISO_8859_4;
+package Locale::RecodeData::ISO_8859_9;
 
 use strict;
 
@@ -187,101 +187,101 @@ my @to_ucs4 = (
     0x009e,
     0x009f,
     0x00a0,
-    0x0104,
-    0x0138,
-    0x0156,
+    0x00a1,
+    0x00a2,
+    0x00a3,
     0x00a4,
-    0x0128,
-    0x013b,
+    0x00a5,
+    0x00a6,
     0x00a7,
     0x00a8,
-    0x0160,
-    0x0112,
-    0x0122,
-    0x0166,
+    0x00a9,
+    0x00aa,
+    0x00ab,
+    0x00ac,
     0x00ad,
-    0x017d,
+    0x00ae,
     0x00af,
     0x00b0,
-    0x0105,
-    0x02db,
-    0x0157,
+    0x00b1,
+    0x00b2,
+    0x00b3,
     0x00b4,
-    0x0129,
-    0x013c,
-    0x02c7,
+    0x00b5,
+    0x00b6,
+    0x00b7,
     0x00b8,
-    0x0161,
-    0x0113,
-    0x0123,
-    0x0167,
-    0x014a,
-    0x017e,
-    0x014b,
-    0x0100,
+    0x00b9,
+    0x00ba,
+    0x00bb,
+    0x00bc,
+    0x00bd,
+    0x00be,
+    0x00bf,
+    0x00c0,
     0x00c1,
     0x00c2,
     0x00c3,
     0x00c4,
     0x00c5,
     0x00c6,
-    0x012e,
-    0x010c,
+    0x00c7,
+    0x00c8,
     0x00c9,
-    0x0118,
+    0x00ca,
     0x00cb,
-    0x0116,
+    0x00cc,
     0x00cd,
     0x00ce,
-    0x012a,
-    0x0110,
-    0x0145,
-    0x014c,
-    0x0136,
+    0x00cf,
+    0x011e,
+    0x00d1,
+    0x00d2,
+    0x00d3,
     0x00d4,
     0x00d5,
     0x00d6,
     0x00d7,
     0x00d8,
-    0x0172,
+    0x00d9,
     0x00da,
     0x00db,
     0x00dc,
-    0x0168,
-    0x016a,
+    0x0130,
+    0x015e,
     0x00df,
-    0x0101,
+    0x00e0,
     0x00e1,
     0x00e2,
     0x00e3,
     0x00e4,
     0x00e5,
     0x00e6,
-    0x012f,
-    0x010d,
+    0x00e7,
+    0x00e8,
     0x00e9,
-    0x0119,
+    0x00ea,
     0x00eb,
-    0x0117,
+    0x00ec,
     0x00ed,
     0x00ee,
-    0x012b,
-    0x0111,
-    0x0146,
-    0x014d,
-    0x0137,
+    0x00ef,
+    0x011f,
+    0x00f1,
+    0x00f2,
+    0x00f3,
     0x00f4,
     0x00f5,
     0x00f6,
     0x00f7,
     0x00f8,
-    0x0173,
+    0x00f9,
     0x00fa,
     0x00fb,
     0x00fc,
-    0x0169,
-    0x016b,
-    0x02d9,
+    0x0131,
+    0x015f,
+    0x00ff,
 );
 
 my @to_utf8 = (
@@ -446,101 +446,101 @@ my @to_utf8 = (
     "\xc2\x9e",
     "\xc2\x9f",
     "\xc2\xa0",
-    "\xc4\x84",
-    "\xc4\xb8",
-    "\xc5\x96",
+    "\xc2\xa1",
+    "\xc2\xa2",
+    "\xc2\xa3",
     "\xc2\xa4",
-    "\xc4\xa8",
-    "\xc4\xbb",
+    "\xc2\xa5",
+    "\xc2\xa6",
     "\xc2\xa7",
     "\xc2\xa8",
-    "\xc5\xa0",
-    "\xc4\x92",
-    "\xc4\xa2",
-    "\xc5\xa6",
+    "\xc2\xa9",
+    "\xc2\xaa",
+    "\xc2\xab",
+    "\xc2\xac",
     "\xc2\xad",
-    "\xc5\xbd",
+    "\xc2\xae",
     "\xc2\xaf",
     "\xc2\xb0",
-    "\xc4\x85",
-    "\xcb\x9b",
-    "\xc5\x97",
+    "\xc2\xb1",
+    "\xc2\xb2",
+    "\xc2\xb3",
     "\xc2\xb4",
-    "\xc4\xa9",
-    "\xc4\xbc",
-    "\xcb\x87",
+    "\xc2\xb5",
+    "\xc2\xb6",
+    "\xc2\xb7",
     "\xc2\xb8",
-    "\xc5\xa1",
-    "\xc4\x93",
-    "\xc4\xa3",
-    "\xc5\xa7",
-    "\xc5\x8a",
-    "\xc5\xbe",
-    "\xc5\x8b",
-    "\xc4\x80",
+    "\xc2\xb9",
+    "\xc2\xba",
+    "\xc2\xbb",
+    "\xc2\xbc",
+    "\xc2\xbd",
+    "\xc2\xbe",
+    "\xc2\xbf",
+    "\xc3\x80",
     "\xc3\x81",
     "\xc3\x82",
     "\xc3\x83",
     "\xc3\x84",
     "\xc3\x85",
     "\xc3\x86",
-    "\xc4\xae",
-    "\xc4\x8c",
+    "\xc3\x87",
+    "\xc3\x88",
     "\xc3\x89",
-    "\xc4\x98",
+    "\xc3\x8a",
     "\xc3\x8b",
-    "\xc4\x96",
+    "\xc3\x8c",
     "\xc3\x8d",
     "\xc3\x8e",
-    "\xc4\xaa",
-    "\xc4\x90",
-    "\xc5\x85",
-    "\xc5\x8c",
-    "\xc4\xb6",
+    "\xc3\x8f",
+    "\xc4\x9e",
+    "\xc3\x91",
+    "\xc3\x92",
+    "\xc3\x93",
     "\xc3\x94",
     "\xc3\x95",
     "\xc3\x96",
     "\xc3\x97",
     "\xc3\x98",
-    "\xc5\xb2",
+    "\xc3\x99",
     "\xc3\x9a",
     "\xc3\x9b",
     "\xc3\x9c",
-    "\xc5\xa8",
-    "\xc5\xaa",
+    "\xc4\xb0",
+    "\xc5\x9e",
     "\xc3\x9f",
-    "\xc4\x81",
+    "\xc3\xa0",
     "\xc3\xa1",
     "\xc3\xa2",
     "\xc3\xa3",
     "\xc3\xa4",
     "\xc3\xa5",
     "\xc3\xa6",
-    "\xc4\xaf",
-    "\xc4\x8d",
+    "\xc3\xa7",
+    "\xc3\xa8",
     "\xc3\xa9",
-    "\xc4\x99",
+    "\xc3\xaa",
     "\xc3\xab",
-    "\xc4\x97",
+    "\xc3\xac",
     "\xc3\xad",
     "\xc3\xae",
-    "\xc4\xab",
-    "\xc4\x91",
-    "\xc5\x86",
-    "\xc5\x8d",
-    "\xc4\xb7",
+    "\xc3\xaf",
+    "\xc4\x9f",
+    "\xc3\xb1",
+    "\xc3\xb2",
+    "\xc3\xb3",
     "\xc3\xb4",
     "\xc3\xb5",
     "\xc3\xb6",
     "\xc3\xb7",
     "\xc3\xb8",
-    "\xc5\xb3",
+    "\xc3\xb9",
     "\xc3\xba",
     "\xc3\xbb",
     "\xc3\xbc",
-    "\xc5\xa9",
-    "\xc5\xab",
-    "\xcb\x99",
+    "\xc4\xb1",
+    "\xc5\x9f",
+    "\xc3\xbf",
 );
 
 my %from_ucs4 = (
@@ -705,101 +705,101 @@ my %from_ucs4 = (
     0x0000009e => "\x9e",
     0x0000009f => "\x9f",
     0x000000a0 => "\xa0",
+    0x000000a1 => "\xa1",
+    0x000000a2 => "\xa2",
+    0x000000a3 => "\xa3",
     0x000000a4 => "\xa4",
+    0x000000a5 => "\xa5",
+    0x000000a6 => "\xa6",
     0x000000a7 => "\xa7",
     0x000000a8 => "\xa8",
+    0x000000a9 => "\xa9",
+    0x000000aa => "\xaa",
+    0x000000ab => "\xab",
+    0x000000ac => "\xac",
     0x000000ad => "\xad",
+    0x000000ae => "\xae",
     0x000000af => "\xaf",
     0x000000b0 => "\xb0",
+    0x000000b1 => "\xb1",
+    0x000000b2 => "\xb2",
+    0x000000b3 => "\xb3",
     0x000000b4 => "\xb4",
+    0x000000b5 => "\xb5",
+    0x000000b6 => "\xb6",
+    0x000000b7 => "\xb7",
     0x000000b8 => "\xb8",
+    0x000000b9 => "\xb9",
+    0x000000ba => "\xba",
+    0x000000bb => "\xbb",
+    0x000000bc => "\xbc",
+    0x000000bd => "\xbd",
+    0x000000be => "\xbe",
+    0x000000bf => "\xbf",
+    0x000000c0 => "\xc0",
     0x000000c1 => "\xc1",
     0x000000c2 => "\xc2",
     0x000000c3 => "\xc3",
     0x000000c4 => "\xc4",
     0x000000c5 => "\xc5",
     0x000000c6 => "\xc6",
+    0x000000c7 => "\xc7",
+    0x000000c8 => "\xc8",
     0x000000c9 => "\xc9",
+    0x000000ca => "\xca",
     0x000000cb => "\xcb",
+    0x000000cc => "\xcc",
     0x000000cd => "\xcd",
     0x000000ce => "\xce",
+    0x000000cf => "\xcf",
+    0x000000d1 => "\xd1",
+    0x000000d2 => "\xd2",
+    0x000000d3 => "\xd3",
     0x000000d4 => "\xd4",
     0x000000d5 => "\xd5",
     0x000000d6 => "\xd6",
     0x000000d7 => "\xd7",
     0x000000d8 => "\xd8",
+    0x000000d9 => "\xd9",
     0x000000da => "\xda",
     0x000000db => "\xdb",
     0x000000dc => "\xdc",
     0x000000df => "\xdf",
+    0x000000e0 => "\xe0",
     0x000000e1 => "\xe1",
     0x000000e2 => "\xe2",
     0x000000e3 => "\xe3",
     0x000000e4 => "\xe4",
     0x000000e5 => "\xe5",
     0x000000e6 => "\xe6",
+    0x000000e7 => "\xe7",
+    0x000000e8 => "\xe8",
     0x000000e9 => "\xe9",
+    0x000000ea => "\xea",
     0x000000eb => "\xeb",
+    0x000000ec => "\xec",
     0x000000ed => "\xed",
     0x000000ee => "\xee",
+    0x000000ef => "\xef",
+    0x000000f1 => "\xf1",
+    0x000000f2 => "\xf2",
+    0x000000f3 => "\xf3",
     0x000000f4 => "\xf4",
     0x000000f5 => "\xf5",
     0x000000f6 => "\xf6",
     0x000000f7 => "\xf7",
     0x000000f8 => "\xf8",
+    0x000000f9 => "\xf9",
     0x000000fa => "\xfa",
     0x000000fb => "\xfb",
     0x000000fc => "\xfc",
-    0x00000100 => "\xc0",
-    0x00000101 => "\xe0",
-    0x00000104 => "\xa1",
-    0x00000105 => "\xb1",
-    0x0000010c => "\xc8",
-    0x0000010d => "\xe8",
-    0x00000110 => "\xd0",
-    0x00000111 => "\xf0",
-    0x00000112 => "\xaa",
-    0x00000113 => "\xba",
-    0x00000116 => "\xcc",
-    0x00000117 => "\xec",
-    0x00000118 => "\xca",
-    0x00000119 => "\xea",
-    0x00000122 => "\xab",
-    0x00000123 => "\xbb",
-    0x00000128 => "\xa5",
-    0x00000129 => "\xb5",
-    0x0000012a => "\xcf",
-    0x0000012b => "\xef",
-    0x0000012e => "\xc7",
-    0x0000012f => "\xe7",
-    0x00000136 => "\xd3",
-    0x00000137 => "\xf3",
-    0x00000138 => "\xa2",
-    0x0000013b => "\xa6",
-    0x0000013c => "\xb6",
-    0x00000145 => "\xd1",
-    0x00000146 => "\xf1",
-    0x0000014a => "\xbd",
-    0x0000014b => "\xbf",
-    0x0000014c => "\xd2",
-    0x0000014d => "\xf2",
-    0x00000156 => "\xa3",
-    0x00000157 => "\xb3",
-    0x00000160 => "\xa9",
-    0x00000161 => "\xb9",
-    0x00000166 => "\xac",
-    0x00000167 => "\xbc",
-    0x00000168 => "\xdd",
-    0x00000169 => "\xfd",
-    0x0000016a => "\xde",
-    0x0000016b => "\xfe",
-    0x00000172 => "\xd9",
-    0x00000173 => "\xf9",
-    0x0000017d => "\xae",
-    0x0000017e => "\xbe",
-    0x000002c7 => "\xb7",
-    0x000002d9 => "\xff",
-    0x000002db => "\xb2",
+    0x000000ff => "\xff",
+    0x0000011e => "\xd0",
+    0x0000011f => "\xf0",
+    0x00000130 => "\xdd",
+    0x00000131 => "\xfd",
+    0x0000015e => "\xde",
+    0x0000015f => "\xfe",
 );
 
 sub _recode
@@ -827,7 +827,7 @@ __END__
 
 =head1 NAME
 
-Locale::RecodeData::ISO_8859_4 - Conversion routines for ISO-8859-4
+Locale::RecodeData::ISO_8859_9 - Conversion routines for ISO-8859-9
 
 =head1 SYNOPSIS
 
@@ -836,7 +836,7 @@ This module is internal to libintl.  Do not use directly!
 =head1 DESCRIPTION
 
 This module is generated and contains the conversion tables and
-routines for ISO-8859-4.
+routines for ISO-8859-9.
 
 =head1 COMMENTS
 
@@ -844,11 +844,11 @@ The following comments have been extracted from the original charmap:
 
  version: 1.0
   source: ECMA registry
- alias ISO-IR-110
- alias ISO_8859-4:1988
- alias ISO_8859-4
- alias LATIN4
- alias L4
+ alias ISO-IR-148
+ alias ISO_8859-9:1989
+ alias ISO_8859-9
+ alias LATIN5
+ alias L5
 
 Please note that aliases listed above are not necessarily valid!
 
@@ -1021,101 +1021,101 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     9E |  0000009E | PRIVACY MESSAGE (PM)
     9F |  0000009F | APPLICATION PROGRAM COMMAND (APC)
     A0 |  000000A0 | NO-BREAK SPACE
-    A1 |  00000104 | LATIN CAPITAL LETTER A WITH OGONEK
-    A2 |  00000138 | LATIN SMALL LETTER KRA (Greenlandic)
-    A3 |  00000156 | LATIN CAPITAL LETTER R WITH CEDILLA
+    A1 |  000000A1 | INVERTED EXCLAMATION MARK
+    A2 |  000000A2 | CENT SIGN
+    A3 |  000000A3 | POUND SIGN
     A4 |  000000A4 | CURRENCY SIGN
-    A5 |  00000128 | LATIN CAPITAL LETTER I WITH TILDE
-    A6 |  0000013B | LATIN CAPITAL LETTER L WITH CEDILLA
+    A5 |  000000A5 | YEN SIGN
+    A6 |  000000A6 | BROKEN BAR
     A7 |  000000A7 | SECTION SIGN
     A8 |  000000A8 | DIAERESIS
-    A9 |  00000160 | LATIN CAPITAL LETTER S WITH CARON
-    AA |  00000112 | LATIN CAPITAL LETTER E WITH MACRON
-    AB |  00000122 | LATIN CAPITAL LETTER G WITH CEDILLA
-    AC |  00000166 | LATIN CAPITAL LETTER T WITH STROKE
+    A9 |  000000A9 | COPYRIGHT SIGN
+    AA |  000000AA | FEMININE ORDINAL INDICATOR
+    AB |  000000AB | LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
+    AC |  000000AC | NOT SIGN
     AD |  000000AD | SOFT HYPHEN
-    AE |  0000017D | LATIN CAPITAL LETTER Z WITH CARON
+    AE |  000000AE | REGISTERED SIGN
     AF |  000000AF | MACRON
     B0 |  000000B0 | DEGREE SIGN
-    B1 |  00000105 | LATIN SMALL LETTER A WITH OGONEK
-    B2 |  000002DB | OGONEK
-    B3 |  00000157 | LATIN SMALL LETTER R WITH CEDILLA
+    B1 |  000000B1 | PLUS-MINUS SIGN
+    B2 |  000000B2 | SUPERSCRIPT TWO
+    B3 |  000000B3 | SUPERSCRIPT THREE
     B4 |  000000B4 | ACUTE ACCENT
-    B5 |  00000129 | LATIN SMALL LETTER I WITH TILDE
-    B6 |  0000013C | LATIN SMALL LETTER L WITH CEDILLA
-    B7 |  000002C7 | CARON (Mandarin Chinese third tone)
+    B5 |  000000B5 | MICRO SIGN
+    B6 |  000000B6 | PILCROW SIGN
+    B7 |  000000B7 | MIDDLE DOT
     B8 |  000000B8 | CEDILLA
-    B9 |  00000161 | LATIN SMALL LETTER S WITH CARON
-    BA |  00000113 | LATIN SMALL LETTER E WITH MACRON
-    BB |  00000123 | LATIN SMALL LETTER G WITH CEDILLA
-    BC |  00000167 | LATIN SMALL LETTER T WITH STROKE
-    BD |  0000014A | LATIN CAPITAL LETTER ENG (Sami)
-    BE |  0000017E | LATIN SMALL LETTER Z WITH CARON
-    BF |  0000014B | LATIN SMALL LETTER ENG (Sami)
-    C0 |  00000100 | LATIN CAPITAL LETTER A WITH MACRON
+    B9 |  000000B9 | SUPERSCRIPT ONE
+    BA |  000000BA | MASCULINE ORDINAL INDICATOR
+    BB |  000000BB | RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
+    BC |  000000BC | VULGAR FRACTION ONE QUARTER
+    BD |  000000BD | VULGAR FRACTION ONE HALF
+    BE |  000000BE | VULGAR FRACTION THREE QUARTERS
+    BF |  000000BF | INVERTED QUESTION MARK
+    C0 |  000000C0 | LATIN CAPITAL LETTER A WITH GRAVE
     C1 |  000000C1 | LATIN CAPITAL LETTER A WITH ACUTE
     C2 |  000000C2 | LATIN CAPITAL LETTER A WITH CIRCUMFLEX
     C3 |  000000C3 | LATIN CAPITAL LETTER A WITH TILDE
     C4 |  000000C4 | LATIN CAPITAL LETTER A WITH DIAERESIS
     C5 |  000000C5 | LATIN CAPITAL LETTER A WITH RING ABOVE
     C6 |  000000C6 | LATIN CAPITAL LETTER AE
-    C7 |  0000012E | LATIN CAPITAL LETTER I WITH OGONEK
-    C8 |  0000010C | LATIN CAPITAL LETTER C WITH CARON
+    C7 |  000000C7 | LATIN CAPITAL LETTER C WITH CEDILLA
+    C8 |  000000C8 | LATIN CAPITAL LETTER E WITH GRAVE
     C9 |  000000C9 | LATIN CAPITAL LETTER E WITH ACUTE
-    CA |  00000118 | LATIN CAPITAL LETTER E WITH OGONEK
+    CA |  000000CA | LATIN CAPITAL LETTER E WITH CIRCUMFLEX
     CB |  000000CB | LATIN CAPITAL LETTER E WITH DIAERESIS
-    CC |  00000116 | LATIN CAPITAL LETTER E WITH DOT ABOVE
+    CC |  000000CC | LATIN CAPITAL LETTER I WITH GRAVE
     CD |  000000CD | LATIN CAPITAL LETTER I WITH ACUTE
     CE |  000000CE | LATIN CAPITAL LETTER I WITH CIRCUMFLEX
-    CF |  0000012A | LATIN CAPITAL LETTER I WITH MACRON
-    D0 |  00000110 | LATIN CAPITAL LETTER D WITH STROKE
-    D1 |  00000145 | LATIN CAPITAL LETTER N WITH CEDILLA
-    D2 |  0000014C | LATIN CAPITAL LETTER O WITH MACRON
-    D3 |  00000136 | LATIN CAPITAL LETTER K WITH CEDILLA
+    CF |  000000CF | LATIN CAPITAL LETTER I WITH DIAERESIS
+    D0 |  0000011E | LATIN CAPITAL LETTER G WITH BREVE
+    D1 |  000000D1 | LATIN CAPITAL LETTER N WITH TILDE
+    D2 |  000000D2 | LATIN CAPITAL LETTER O WITH GRAVE
+    D3 |  000000D3 | LATIN CAPITAL LETTER O WITH ACUTE
     D4 |  000000D4 | LATIN CAPITAL LETTER O WITH CIRCUMFLEX
     D5 |  000000D5 | LATIN CAPITAL LETTER O WITH TILDE
     D6 |  000000D6 | LATIN CAPITAL LETTER O WITH DIAERESIS
     D7 |  000000D7 | MULTIPLICATION SIGN
     D8 |  000000D8 | LATIN CAPITAL LETTER O WITH STROKE
-    D9 |  00000172 | LATIN CAPITAL LETTER U WITH OGONEK
+    D9 |  000000D9 | LATIN CAPITAL LETTER U WITH GRAVE
     DA |  000000DA | LATIN CAPITAL LETTER U WITH ACUTE
     DB |  000000DB | LATIN CAPITAL LETTER U WITH CIRCUMFLEX
     DC |  000000DC | LATIN CAPITAL LETTER U WITH DIAERESIS
-    DD |  00000168 | LATIN CAPITAL LETTER U WITH TILDE
-    DE |  0000016A | LATIN CAPITAL LETTER U WITH MACRON
+    DD |  00000130 | LATIN CAPITAL LETTER I WITH DOT ABOVE
+    DE |  0000015E | LATIN CAPITAL LETTER S WITH CEDILLA
     DF |  000000DF | LATIN SMALL LETTER SHARP S (German)
-    E0 |  00000101 | LATIN SMALL LETTER A WITH MACRON
+    E0 |  000000E0 | LATIN SMALL LETTER A WITH GRAVE
     E1 |  000000E1 | LATIN SMALL LETTER A WITH ACUTE
     E2 |  000000E2 | LATIN SMALL LETTER A WITH CIRCUMFLEX
     E3 |  000000E3 | LATIN SMALL LETTER A WITH TILDE
     E4 |  000000E4 | LATIN SMALL LETTER A WITH DIAERESIS
     E5 |  000000E5 | LATIN SMALL LETTER A WITH RING ABOVE
     E6 |  000000E6 | LATIN SMALL LETTER AE
-    E7 |  0000012F | LATIN SMALL LETTER I WITH OGONEK
-    E8 |  0000010D | LATIN SMALL LETTER C WITH CARON
+    E7 |  000000E7 | LATIN SMALL LETTER C WITH CEDILLA
+    E8 |  000000E8 | LATIN SMALL LETTER E WITH GRAVE
     E9 |  000000E9 | LATIN SMALL LETTER E WITH ACUTE
-    EA |  00000119 | LATIN SMALL LETTER E WITH OGONEK
+    EA |  000000EA | LATIN SMALL LETTER E WITH CIRCUMFLEX
     EB |  000000EB | LATIN SMALL LETTER E WITH DIAERESIS
-    EC |  00000117 | LATIN SMALL LETTER E WITH DOT ABOVE
+    EC |  000000EC | LATIN SMALL LETTER I WITH GRAVE
     ED |  000000ED | LATIN SMALL LETTER I WITH ACUTE
     EE |  000000EE | LATIN SMALL LETTER I WITH CIRCUMFLEX
-    EF |  0000012B | LATIN SMALL LETTER I WITH MACRON
-    F0 |  00000111 | LATIN SMALL LETTER D WITH STROKE
-    F1 |  00000146 | LATIN SMALL LETTER N WITH CEDILLA
-    F2 |  0000014D | LATIN SMALL LETTER O WITH MACRON
-    F3 |  00000137 | LATIN SMALL LETTER K WITH CEDILLA
+    EF |  000000EF | LATIN SMALL LETTER I WITH DIAERESIS
+    F0 |  0000011F | LATIN SMALL LETTER G WITH BREVE
+    F1 |  000000F1 | LATIN SMALL LETTER N WITH TILDE
+    F2 |  000000F2 | LATIN SMALL LETTER O WITH GRAVE
+    F3 |  000000F3 | LATIN SMALL LETTER O WITH ACUTE
     F4 |  000000F4 | LATIN SMALL LETTER O WITH CIRCUMFLEX
     F5 |  000000F5 | LATIN SMALL LETTER O WITH TILDE
     F6 |  000000F6 | LATIN SMALL LETTER O WITH DIAERESIS
     F7 |  000000F7 | DIVISION SIGN
     F8 |  000000F8 | LATIN SMALL LETTER O WITH STROKE
-    F9 |  00000173 | LATIN SMALL LETTER U WITH OGONEK
+    F9 |  000000F9 | LATIN SMALL LETTER U WITH GRAVE
     FA |  000000FA | LATIN SMALL LETTER U WITH ACUTE
     FB |  000000FB | LATIN SMALL LETTER U WITH CIRCUMFLEX
     FC |  000000FC | LATIN SMALL LETTER U WITH DIAERESIS
-    FD |  00000169 | LATIN SMALL LETTER U WITH TILDE
-    FE |  0000016B | LATIN SMALL LETTER U WITH MACRON
-    FF |  000002D9 | DOT ABOVE (Mandarin Chinese light tone)
+    FD |  00000131 | LATIN SMALL LETTER DOTLESS I
+    FE |  0000015F | LATIN SMALL LETTER S WITH CEDILLA
+    FF |  000000FF | LATIN SMALL LETTER Y WITH DIAERESIS
 
 
 =head1 AUTHOR
@@ -1141,4 +1141,3 @@ cperl-indent-level: 4
 cperl-continued-statement-offset: 2
 tab-width: 4
 End:
-=cut
